LacunaBanner class
- Inheritance
-
- Object
- LacunaAd
- LacunaAdWithView
- LacunaBanner
Constructors
- LacunaBanner({required String placeId, AdSize? adSize, AdLoadListener? adLoadListener, AdActionListener? adActionListener})
Properties
- adSize ↔ AdSize?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- placeId ↔ String
-
getter/setter pair
- requestId ↔ String?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewType → String
-
no setteroverride
Methods
-
dispose(
) → Future< void> -
inherited
-
load(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited